#! /usr/bin/env python3
# -*- coding:utf-8 -*-

import math

from icm20649_spi.table import flatten

class Decimator:

    lastLinesMin = []
    lastLinesMax = []
    lastLinesMean = []
    decimate = 10
    ncols = 3
    nlines = 0

    def __init__(self, decimate, ncols, output, action):
        self.decimate = decimate
        if self.decimate < 1:
            print(f'Warning: decimate is zero or below: {self.decimate}, setting to 1')
            self.decimate = 1
        self.ncols = ncols
        self.reset()
        self.outputHandle = output
        self.actionHandle = action

    def reset(self):
        self.lastLinesMin = [ math.inf] * self.ncols
        self.lastLinesMax = [-math.inf] * self.ncols
        self.lastLinesMean = [0] * self.ncols

    def processValues(self, items):
        self.nlines += 1

        for (i, val) in enumerate(items):
            self.lastLinesMin[i] = min(self.lastLinesMin[i], val)
            self.lastLinesMax[i] = max(self.lastLinesMax[i], val)
            self.lastLinesMean[i] += val

        if self.nlines % self.decimate == 0:
            # self.actionHandle(self.lastLinesMin, 'min')
            # self.actionHandle(self.lastLinesMax, 'max')
            self.actionHandle(self.lastLinesMin + self.lastLinesMax, 'minmax')
            self.lastLinesMean = [ m/self.decimate for m in self.lastLinesMean ]
            oitems = flatten([ (self.lastLinesMin[i], self.lastLinesMean[i], self.lastLinesMax[i]) for i in range(self.ncols) ])
            self.outputHandle(oitems)
            self.reset()
