#! /usr/bin/env python3

from icm20649_spi.spitool import SPIConn
import time
import argparse
import math

from icm20649_spi.icm20649 import ICM20649

def parseargs():
  parser = argparse.ArgumentParser(description='Erzeuge Umspul-Konfiguration.')

  parser.add_argument('--bus', dest='bus', type=int, default=0, help='SPI bus')
  parser.add_argument('--dev', dest='dev', type=int, default=0, help='SPI device')
  parser.add_argument('--speed', dest='speed', type=int, default=int(1e6), help='SPI speed')

  parser.add_argument('bank', metavar='bank', type=int, nargs='?', help='Bank (0-3)')
  parser.add_argument('reg', metavar='reg', type=int, nargs='?', help='Reg (0-3)')
  parser.add_argument('val', metavar='val', type=int, nargs='?', help='Val (0-3)')

  parser.add_argument('--show', action='store_true', help='SPI speed')

  args = parser.parse_args()
  return args

def run():
  args = parseargs()

  spi = SPIConn(args.bus, args.dev, args.speed)

  icm20649 = ICM20649(spi)
  if not icm20649.connected:
    print("device not found")
    return

  if args.show:
    print(icm20649)
    return

  icm20649.setUserBank(args.bank)
  val = icm20649.get(args.reg)

  print('Get Bank %d Reg 0x%x = %d (0x%x, %s)' % (args.bank, args.reg, val, val, bin(val)))

  icm20649.setUserBank(0)

if __name__ == "__main__":
  run()
