from . import ads1015

import math
import time

myads1015 = ads1015.ADS1015()

FSR = 2.048 # V

vplus = 3.31

cntMax = 2047

cntMaxEff = (vplus/FSR) * cntMax

volt_In = 3.3   # 5 V
res_R2 = 10e3   # 10 kOhm

ntc_param_B = 3900
avail_channels = channels = [2, 3]
opts = {'raw': False, 'voltage': False, 'resistance': False, 'odr': 1600, 'celsius': True, 'kelvin': False}

def init(cs, **kw):
    global channels
    global opts
    global res_R2, volt_In, ntc_param_B

    channels = cs

    for i in kw:
        if i in opts:
            opts[i] = kw[i]

    if 'constant_R2' in kw:
        res_R2 = kw['constant_R2']
    if 'constant_Vin' in kw:
        volt_In = kw['constant_Vin']
    if 'constant_B' in kw:
        ntc_param_B = kw['constant_B']

def adread(channel=0):
    ch = channels[channel]
    myads1015.ADS1015_SET_CHANNEL(ch)
    time.sleep(1e-2)
    value = myads1015.ADS1015_RESULT()
    return value

def adread1(channel=0):
    ch = channels[channel]
    value = myads1015.ADS1015_SINGLE_READ(ch, opts['odr'])
    return value

def clean(value):
    if value == 4095:
        value = 0
    return value

def voltage(value):
    return clean(value) * 2e-3

def resistance(value):
    volt = voltage(value)
    divi = (volt_In/volt - 1) if volt else math.inf
    if divi < 0:
        divi = 0
    if divi:
        return res_R2 / divi
    else:
        return math.inf

def temperature(value):
    res = resistance(value)
    #print('B', ntc_param_B, value, 'V', voltage(value), 'Ohm', resistance(value))
    divi = (1/ntc_param_B) * math.log(res / res_R2) + 1 / 298.15
    temp = 1 / divi
    return temp

def temperatureC(value):
    return temperature(value) - 273.15

def read(channel=0):
    value = adread1(channel)
    res = []
    if opts['raw']:
        res += [value]
    if opts['voltage']:
        res += [voltage(value)]
    if opts['resistance']:
        res += [resistance(value)]
    if opts['kelvin']:
        res += [temperature(value)]
    if opts['celsius']:
        res += [temperatureC(value)]
    if len(res) == 1:
        res = res[0]
    return res

def readall():
    vals = [read(ci) for ci in range(len(channels))]
    return vals

def run():
    import time, argparse

    parser = argparse.ArgumentParser(description='Test ADS1015 ADC.')

    parser.add_argument('channels', metavar='C', type=int, nargs='+', help='Channels')
    parser.add_argument('--raw', '-r', action='store_true', help='Print ADC raw values')
    parser.add_argument('--voltage', '-V', action='store_true', help='Print ADC voltages')
    parser.add_argument('--resistance', '-R', action='store_true', help='Print ADC Resistance')

    parser.add_argument('--odr', type=int, help='Print ADC voltages')

    parser.add_argument('--constant-R2', type=float, default=res_R2, help='Set other resistor')
    parser.add_argument('--constant-Vin', type=float, default=volt_In, help='Set NTC constant B')
    parser.add_argument('--constant-B', '-B', type=float, default=ntc_param_B, help='Set NTC constant B')

    args = parser.parse_args()
    print(args)

    init(args.channels, **vars(args))

    while True:
        t0 = time.time()
        vals = readall()
        tconv = time.time() - t0
        print(vals, '°C', '%.2f ms' %(tconv * 1e3,))
        time.sleep(1)

if __name__ == "__main__":
    run()
